@@ -14,12 +14,11 @@ try:
     import boto3
     import boto3.session
     import botocore.session
-except ImportError as e:
+except ImportError as e:  # pragma: no cover
     print("You probably need to install 'boto3' first.")
 
 if T.TYPE_CHECKING:  # pragma: no cover
     from botocore.client import BaseClient
-    from botocore.credentials import Credentials
     from boto3.resources.base import ServiceResource
 
 from .services import AwsServiceEnum
@@ -59,7 +58,7 @@ class BotoSesManager(ClientMixin):
         self.aws_secret_access_key = aws_secret_access_key
         self.aws_session_token = aws_session_token
         self.region_name = region_name
-        if botocore_session is not None:
+        if botocore_session is not None:  # pragma: no cover
             if not isinstance(botocore_session, botocore.session.Session):
                 raise TypeError
         self.botocore_session: "botocore.session.Session" = botocore_session
@@ -161,7 +160,7 @@ class BotoSesManager(ClientMixin):
             )
             client_kwargs = {k: v for k, v in client_kwargs.items() if v is not None}
             kwargs = dict(self.default_client_kwargs)
-            if self.default_client_kwargs:
+            if self.default_client_kwargs:  # pragma: no cover
                 kwargs.update(client_kwargs)
             client = self.boto_ses.client(service_name, **kwargs)
             self._client_cache[service_name] = client
@@ -271,7 +270,12 @@ class BotoSesManager(ClientMixin):
         ) >= self.expiration_time
 
     @contextlib.contextmanager
-    def awscli(self) -> "BotoSesManager":
+    def awscli(
+        self,
+        duration_seconds: int = 900,
+        serial_number: T.Optional[str] = None,
+        token_code: T.Optional[str] = None,
+    ) -> "BotoSesManager":
         """
         Temporarily set up environment variable to pass the boto session
         credential to AWS CLI.
@@ -301,41 +305,38 @@ class BotoSesManager(ClientMixin):
         ]
         env_var = dict()
         for env_name in env_names:
-            if env_name in os.environ:
+            if env_name in os.environ:  # pragma: no cover
                 env_var[env_name] = os.environ[env_name]
             else:
                 env_var[env_name] = None
 
         # set environment variable for aws cli
-        if self.botocore_session is None:
-            if self.aws_access_key_id:
-                os.environ["AWS_ACCESS_KEY_ID"] = self.aws_access_key_id
-            if self.aws_secret_access_key:
-                os.environ["AWS_SECRET_ACCESS_KEY"] = self.aws_secret_access_key
-            if self.aws_session_token:
-                os.environ["AWS_SESSION_TOKEN"] = self.aws_session_token
-            if self.region_name:
-                os.environ["AWS_REGION"] = self.region_name
-            if self.profile_name:
-                os.environ["AWS_PROFILE"] = self.profile_name
+        if (
+            (self.aws_access_key_id is not None)
+            and (self.aws_secret_access_key is not None)
+            and (self.aws_access_key_id is not None)
+        ):
+            os.environ["AWS_ACCESS_KEY_ID"] = self.aws_access_key_id
+            os.environ["AWS_SECRET_ACCESS_KEY"] = self.aws_secret_access_key
+            os.environ["AWS_SESSION_TOKEN"] = self.aws_session_token
+            os.environ["AWS_REGION"] = self.aws_region
         else:
-            credential: Credentials = self.botocore_session.get_credentials()
-            aws_access_key_id = credential.access_key
-            aws_secret_access_key = credential.secret_key
-            aws_session_token = credential.token
-            profile_name = self.botocore_session.profile
-
-            if aws_access_key_id:
-                os.environ["AWS_ACCESS_KEY_ID"] = aws_access_key_id
-            if aws_secret_access_key:
-                os.environ["AWS_SECRET_ACCESS_KEY"] = aws_secret_access_key
-            if aws_session_token:
-                os.environ["AWS_SESSION_TOKEN"] = aws_session_token
-            if profile_name:
-                os.environ["AWS_PROFILE"] = profile_name
-
+            kwargs = dict(
+                DurationSeconds=duration_seconds,
+            )
+            if serial_number is not None:  # pragma: no cover
+                kwargs["SerialNumber"] = serial_number
+            if token_code is not None:  # pragma: no cover
+                kwargs["TokenCode"] = token_code
+            response = self.sts_client.get_session_token(**kwargs)
+            os.environ["AWS_ACCESS_KEY_ID"] = response["Credentials"]["AccessKeyId"]
+            os.environ["AWS_SECRET_ACCESS_KEY"] = response["Credentials"][
+                "SecretAccessKey"
+            ]
+            os.environ["AWS_SESSION_TOKEN"] = response["Credentials"]["SessionToken"]
+            os.environ["AWS_REGION"] = self.aws_region
         try:
-            yield None
+            yield self
         finally:
             # recover previous existing env var
             for env_name, env_value in env_var.items():
