@@ -44,6 +44,7 @@ class AwsServiceEnum:
     ChimeSDKMeetings = "chime-sdk-meetings"
     ChimeSDKMessaging = "chime-sdk-messaging"
     ChimeSDKVoice = "chime-sdk-voice"
+    CleanRoomsService = "cleanrooms"
     Cloud9 = "cloud9"
     CloudControlApi = "cloudcontrol"
     CloudDirectory = "clouddirectory"
@@ -54,6 +55,7 @@ class AwsServiceEnum:
     CloudSearch = "cloudsearch"
     CloudSearchDomain = "cloudsearchdomain"
     CloudTrail = "cloudtrail"
+    CloudTrailDataService = "cloudtrail-data"
     CloudWatch = "cloudwatch"
     CodeArtifact = "codeartifact"
     CodeBuild = "codebuild"
@@ -147,6 +149,7 @@ class AwsServiceEnum:
     ImportExport = "importexport"
     Inspector = "inspector"
     Inspector2 = "inspector2"
+    CloudWatchInternetMonitor = "internetmonitor"
     IoT = "iot"
     IoTDataPlane = "iot-data"
     IoTJobsDataPlane = "iot-jobs-data"
@@ -169,11 +172,13 @@ class AwsServiceEnum:
     Kafka = "kafka"
     KafkaConnect = "kafkaconnect"
     kendra = "kendra"
+    KendraRanking = "kendra-ranking"
     Keyspaces = "keyspaces"
     Kinesis = "kinesis"
     KinesisVideoArchivedMedia = "kinesis-video-archived-media"
     KinesisVideoMedia = "kinesis-video-media"
     KinesisVideoSignalingChannels = "kinesis-video-signaling"
+    KinesisVideoWebRTCStorage = "kinesis-video-webrtc-storage"
     KinesisAnalytics = "kinesisanalytics"
     KinesisAnalyticsV2 = "kinesisanalyticsv2"
     KinesisVideo = "kinesisvideo"
@@ -185,6 +190,7 @@ class AwsServiceEnum:
     LexModelsV2 = "lexv2-models"
     LexRuntimeV2 = "lexv2-runtime"
     LicenseManager = "license-manager"
+    LicenseManagerLinuxSubscriptions = "license-manager-linux-subscriptions"
     LicenseManagerUserSubscriptions = "license-manager-user-subscriptions"
     Lightsail = "lightsail"
     LocationService = "location"
@@ -278,6 +284,7 @@ class AwsServiceEnum:
     SagemakerEdgeManager = "sagemaker-edge"
     SageMakerFeatureStoreRuntime = "sagemaker-featurestore-runtime"
     SageMakergeospatialcapabilities = "sagemaker-geospatial"
+    SageMakerMetrics = "sagemaker-metrics"
     SageMakerRuntime = "sagemaker-runtime"
     SavingsPlans = "savingsplans"
     EventBridgeScheduler = "scheduler"
@@ -319,6 +326,7 @@ class AwsServiceEnum:
     Textract = "textract"
     TimestreamQuery = "timestream-query"
     TimestreamWrite = "timestream-write"
+    TelcoNetworkBuilder = "tnb"
     TranscribeService = "transcribe"
     Transfer = "transfer"
     Translate = "translate"
@@ -334,4 +342,4 @@ class AwsServiceEnum:
     WorkMailMessageFlow = "workmailmessageflow"
     WorkSpaces = "workspaces"
     WorkSpacesWeb = "workspaces-web"
-    XRay = "xray"
+    XRay = "xray"
\ No newline at end of file
